# YT MIX SPLITTER
Download all the songs in a youtube mix.  

This script reads the songs in the description and downloads them separetely using youtube-dl.  
### Prerequisites
Since this script uses youtube-dl we need to install some of its dependencies.

`sudo apt-get install ffmpeg`  
`sudo apt-get install atomicparsley`


 